@@ -17,6 +17,8 @@ description:
 version_added: 1.0.0
 requirements:
 - ansible-pylibssh if using I(ssh_type=libssh)
+extends_documentation_fragment:
+- ansible.netcommon.connection_persistent
 options:
   host:
     description:
@@ -140,34 +142,6 @@ options:
       key: host_key_auto_add
     env:
     - name: ANSIBLE_HOST_KEY_AUTO_ADD
-  persistent_connect_timeout:
-    type: int
-    description:
-    - Configures, in seconds, the amount of time to wait when trying to initially
-      establish a persistent connection.  If this value expires before the connection
-      to the remote device is completed, the connection will fail.
-    default: 30
-    ini:
-    - section: persistent_connection
-      key: connect_timeout
-    env:
-    - name: ANSIBLE_PERSISTENT_CONNECT_TIMEOUT
-    vars:
-    - name: ansible_connect_timeout
-  persistent_command_timeout:
-    type: int
-    description:
-    - Configures, in seconds, the amount of time to wait for a command to return from
-      the remote device.  If this timer is exceeded before the command returns, the
-      connection plugin will raise an exception and close.
-    default: 30
-    ini:
-    - section: persistent_connection
-      key: command_timeout
-    env:
-    - name: ANSIBLE_PERSISTENT_COMMAND_TIMEOUT
-    vars:
-    - name: ansible_command_timeout
   persistent_buffer_read_timeout:
     type: float
     description:
@@ -183,23 +157,6 @@ options:
     - name: ANSIBLE_PERSISTENT_BUFFER_READ_TIMEOUT
     vars:
     - name: ansible_buffer_read_timeout
-  persistent_log_messages:
-    type: boolean
-    description:
-    - This flag will enable logging the command executed and response received from
-      target device in the ansible log file. For this option to work 'log_path' ansible
-      configuration option is required to be set to a file path with write access.
-    - Be sure to fully understand the security implications of enabling this option
-      as it could create a security vulnerability by logging sensitive information
-      in log file.
-    default: false
-    ini:
-    - section: persistent_connection
-      key: log_messages
-    env:
-    - name: ANSIBLE_PERSISTENT_LOG_MESSAGES
-    vars:
-    - name: ansible_persistent_log_messages
   terminal_stdout_re:
     type: list
     elements: dict
@@ -460,11 +417,12 @@ class Connection(NetworkConnectionBase):
             )
             self._ssh_type_conn.set_options(
                 direct={
-                    "look_for_keys": not bool(
-                        self._play_context.password
-                        and not self._play_context.private_key_file
-                    ),
                     "host_key_checking": self.get_option("host_key_checking"),
+                    "look_for_keys": not bool(
+                        self.get_option("password")
+                        and not self.get_option("private_key_file")
+                    ),
+                    "password": self.get_option("password"),
                 }
             )
             self.queue_message(
