@@ -68,15 +68,21 @@ class TestIpFilter(unittest.TestCase):
         self.assertEqual(ipaddr.ipaddr("192.0.2.230"), "192.0.2.230")
         self.assertEqual(ipaddr.ipaddr("192.0.2.230/30"), "192.0.2.230/30")
         self.assertEqual(ipaddr.ipaddr([]), [])
-        with pytest.raises(
-            AnsibleFilterError,
-            match="True is not a valid IP address or network",
-        ):
-            ipaddr.ipaddr(True)
-        with pytest.raises(
-            AnsibleFilterError, match="'' is not a valid IP address or network"
-        ):
-            ipaddr.ipaddr("")
+
+        self.assertEqual(ipaddr.ipaddr(True), False)
+        self.assertEqual(ipaddr.ipaddr(""), False)
+
+        # #TODO: Add these test after the check value check for None and True is removed
+        # #TODO: from ipaddr filter
+        # with pytest.raises(
+        #     AnsibleFilterError,
+        #     match="True is not a valid IP address or network",
+        # ):
+        #     ipaddr.ipaddr(True)
+        # with pytest.raises(
+        #     AnsibleFilterError, match="'' is not a valid IP address or network"
+        # ):
+        #     ipaddr.ipaddr("")
 
     def test_ipaddr_6to4_query(self):
         v6_address = "2002:c000:02e6::1/48"
@@ -296,30 +302,46 @@ class TestIpFilter(unittest.TestCase):
         )
 
     def test_address_prefix(self):
+        # Regular address
+        address = "1.12.1.12/24"
+        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), address)
+
+        # Network address - invalid
         address = "1.12.1.0/24"
-        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), None)
-        address = "1.12.1.0/25"
-        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), None)
-        # address = '1.12.1.34'
-        # self.assertFalse(ipaddr.ipaddr(address, 'last_usable'), 'Not a network address')
-        address = "1.12.1.36/28"
+        self.assertFalse(ipaddr.ipaddr(address, "address/prefix"))
+        # But valid in a /31
+        address = "1.12.1.0/31"
+        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), address)
+
+        # Broadcast address - invalid
+        address = "1.12.1.255/24"
+        self.assertFalse(ipaddr.ipaddr(address, "address/prefix"))
+        # But valid in a /31
+        address = "1.12.1.255/31"
+        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), address)
+
+        # /32 - always valid?
+        address = "1.12.1.0/32"
+        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), address)
+        address = "1.12.1.12/32"
+        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), address)
+        address = "1.12.1.255/32"
+        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), address)
+
+        # No prefix means /32
+        address = "1.12.1.34"
         self.assertEqual(
-            ipaddr.ipaddr(address, "address/prefix"), "1.12.1.36/28"
+            ipaddr.ipaddr(address, "address/prefix"), "1.12.1.34/32"
         )
+
+        # Hostmask also works
         address = "1.12.1.36/255.255.255.240"
         self.assertEqual(
             ipaddr.ipaddr(address, "address/prefix"), "1.12.1.36/28"
         )
-        # address = '1.12.1.36/31'
-        # self.assertEqual(ipaddr.ipaddr(address, 'address/prefix'), '1.12.1.36/31') - unfixable?
-        # address = '1.12.1.37/31'
-        # self.assertEqual(ipaddr.ipaddr(address, 'address/prefix'), '1.12.1.37/31') - unfixable?
-        address = "1.12.1.36/32"
-        self.assertEqual(ipaddr.ipaddr(address, "address/prefix"), None)
-        address = "1.12.1.254/24"
-        self.assertEqual(
-            ipaddr.ipaddr(address, "address/prefix"), "1.12.1.254/24"
-        )
+        # But not hostmasks that don't make a valid CIDR prefix
+        address = "1.12.1.36/255.255.255.88"
+        self.assertFalse(ipaddr.ipaddr(address, "address/prefix"))
 
     def test_ip_prefix(self):
         address = "1.12.1.0/24"
