@@ -14,11 +14,11 @@ ANSIBLE_METADATA = {'metadata_version': '1.1', 'status': ['preview'], 'supported
 
 DOCUMENTATION = '''
 ---
-module: tower_job_wait
+module: job_wait
 author: "Wayne Witzel III (@wwitzel3)"
-short_description: Wait for Ansible Tower job to finish.
+short_description: Wait for Automation Platform Controller job to finish.
 description:
-    - Wait for Ansible Tower job to finish and report success or failure. See
+    - Wait for Automation Platform Controller job to finish and report success or failure. See
       U(https://www.ansible.com/tower) for an overview.
 options:
     job_id:
@@ -28,19 +28,19 @@ options:
       type: int
     interval:
       description:
-        - The interval in sections, to request an update from Tower.
+        - The interval in sections, to request an update from the controller.
         - For backwards compatibility if unset this will be set to the average of min and max intervals
       required: False
       default: 1
       type: float
     min_interval:
       description:
-        - Minimum interval in seconds, to request an update from Tower.
+        - Minimum interval in seconds, to request an update from the controller.
         - deprecated, use interval instead
       type: float
     max_interval:
       description:
-        - Maximum interval in seconds, to request an update from Tower.
+        - Maximum interval in seconds, to request an update from the controller.
         - deprecated, use interval instead
       type: float
     timeout:
@@ -58,12 +58,12 @@ extends_documentation_fragment: awx.awx.auth
 
 EXAMPLES = '''
 - name: Launch a job
-  tower_job_launch:
+  job_launch:
     job_template: "My Job Template"
   register: job
 
 - name: Wait for job max 120s
-  tower_job_wait:
+  job_wait:
     job_id: "{{ job.id }}"
     timeout: 120
 '''
@@ -97,7 +97,7 @@ status:
 '''
 
 
-from ..module_utils.tower_api import TowerAPIModule
+from ..module_utils.controller_api import ControllerAPIModule
 
 
 def main():
@@ -112,7 +112,7 @@ def main():
     )
 
     # Create a module for ourselves
-    module = TowerAPIModule(argument_spec=argument_spec)
+    module = ControllerAPIModule(argument_spec=argument_spec)
 
     # Extract our parameters
     job_id = module.params.get('job_id')
@@ -132,8 +132,9 @@ def main():
                 max_interval = 30
             interval = abs((min_interval + max_interval) / 2)
         module.deprecate(
+            collection_name="awx.awx",
             msg="Min and max interval have been deprecated, please use interval instead; interval will be set to {0}".format(interval),
-            version="ansible.tower:4.0.0",
+            version="4.0.0",
         )
 
     # Attempt to look up job based on the provided id
@@ -147,7 +148,7 @@ def main():
     )
 
     if job is None:
-        module.fail_json(msg='Unable to wait on ' + job_type.rstrip("s") + ' {0}; that ID does not exist in Tower.'.format(job_id))
+        module.fail_json(msg='Unable to wait on ' + job_type.rstrip("s") + ' {0}; that ID does not exist.'.format(job_id))
 
     # Invoke wait function
     result = module.wait_on_url(url=job['url'], object_name=job_id, object_type='legacy_job_wait', timeout=timeout, interval=interval)
