@@ -109,6 +109,7 @@ AZURE_API_PROFILES = {
         'MariaDBManagementClient': '2019-03-01',
         'ManagementLockClient': '2016-09-01',
         'DataLakeStoreAccountManagementClient': '2016-11-01',
+        'NotificationHubsManagementClient': '2016-03-01',
         'EventHubManagementClient': '2018-05-04'
     },
     '2019-03-01-hybrid': {
@@ -279,6 +280,7 @@ try:
     from azure.mgmt.search import SearchManagementClient
     from azure.mgmt.datalake.store import DataLakeStoreAccountManagementClient
     import azure.mgmt.datalake.store.models as DataLakeStoreAccountModel
+    from azure.mgmt.notificationhubs import NotificationHubsManagementClient
     from azure.mgmt.eventhub import EventHubManagementClient
 
 except ImportError as exc:
@@ -448,6 +450,7 @@ class AzureRMModuleBase(object):
         self._recovery_services_backup_client = None
         self._search_client = None
         self._datalake_store_client = None
+        self._notification_hub_client = None
         self._event_hub_client = None
 
         self.check_mode = self.module.check_mode
@@ -1131,7 +1134,7 @@ class AzureRMModuleBase(object):
     @property
     def managedcluster_models(self):
         self.log("Getting container service models")
-        return ContainerServiceClient.models('2019-04-01')
+        return ContainerServiceClient.models('2020-04-01')
 
     @property
     def managedcluster_client(self):
@@ -1139,7 +1142,7 @@ class AzureRMModuleBase(object):
         if not self._managedcluster_client:
             self._managedcluster_client = self.get_mgmt_svc_client(ContainerServiceClient,
                                                                    base_url=self._cloud_environment.endpoints.resource_manager,
-                                                                   api_version='2019-04-01')
+                                                                   api_version='2020-04-01')
         return self._managedcluster_client
 
     @property
@@ -1335,6 +1338,16 @@ class AzureRMModuleBase(object):
     def datalake_store_models(self):
         return DataLakeStoreAccountModel
 
+    @property
+    def notification_hub_client(self):
+        self.log('Getting notification hub client')
+        if not self._notification_hub_client:
+            self._notification_hub_client = self.get_mgmt_svc_client(
+                NotificationHubsManagementClient,
+                base_url=self._cloud_environment.endpoints.resource_manager,
+                api_version='2016-03-01')
+        return self._notification_hub_client
+
     @property
     def event_hub_client(self):
         self.log('Getting event hub client')
