@@ -9,68 +9,43 @@ group="${args[0]}"
 
 command -v python
 python -V
-
 if [ "$2" = "2.7" ]
 then
-    command -v pip
-    pip --version
-    pip list --disable-pip-version-check
+    echo "The specified environment is Python2.7"
 else
-    if [ "$2" = "3.8" ]
-    then
-        sudo apt update
-        sudo apt install software-properties-common
-        sudo add-apt-repository ppa:deadsnakes/ppa
-        sudo apt install python"$2" -y
-        sudo update-alternatives --install /usr/bin/python3 python3 /usr/bin/python3.8 1
-    fi
-
-    command -v pip3
-    pip3 --version
-    pip3 list --disable-pip-version-check
+    alias pip='pip3'
+    sudo apt update
+    sudo apt install software-properties-common
+    sudo add-apt-repository ppa:deadsnakes/ppa
+    sudo apt install python"$2" -y
+    sudo update-alternatives --install /usr/bin/python3 python3 /usr/bin/python"$2" 1
 fi
 
+command -v pip
+pip --version
+pip list --disable-pip-version-check
+
 export PATH="${PWD}/bin:${PATH}"
 export PYTHONIOENCODING="UTF-8"
 export LC_ALL="en_US.utf-8"
 
-if [ "$2" = "2.7" ]
-then
-    pip install virtualenv
-    virtualenv --python /usr/bin/python2.7 ~/ansible-venv
-else
-    pip3 install virtualenv
-    virtualenv --python /usr/bin/python"$2" ~/ansible-venv
-fi
+pip install virtualenv
+virtualenv --python /usr/bin/python"$2" ~/ansible-venv
 
 set +ux
 . ~/ansible-venv/bin/activate
 set -ux
 
-if [ "$2" = "2.7" ]
+git clone https://github.com/ansible/ansible.git
+cd "ansible"
+if [ "$3" = "devel" ]
 then
-    if [ "$3" = "devel" ]
-    then
-        pip install git+https://github.com/ansible/ansible.git@devel  --disable-pip-version-check
-    else
-	git clone https://github.com/ansible/ansible.git
-	cd "ansible"
-	git checkout "stable-$3"
-	source hacking/env-setup
-	pip install paramiko PyYAML Jinja2  httplib2 six
-    fi
+    echo "The branch is devel"
 else
-    if [ "$3" = "devel" ]
-    then
-        pip3 install git+https://github.com/ansible/ansible.git@devel  --disable-pip-version-check
-    else
-	git clone https://github.com/ansible/ansible.git
-	cd "ansible"
-	git checkout "stable-$3"
-	source hacking/env-setup
-	pip3 install paramiko PyYAML Jinja2  httplib2 six
-    fi
+    git checkout "stable-$3"
 fi
+source hacking/env-setup
+pip install paramiko PyYAML Jinja2  httplib2 six
 
 TEST_DIR="${HOME}/.ansible/ansible_collections/azure/azcollection"
 mkdir -p "${TEST_DIR}"
@@ -78,20 +53,10 @@ cp -aT "${SHIPPABLE_BUILD_DIR}" "${TEST_DIR}"
 cd "${TEST_DIR}"
 mkdir -p shippable/testresults
 
-if [ "$2" = "2.7" ]
-then
-    pip install --upgrade pip
-    pip install  -I -r "${TEST_DIR}/requirements-azure.txt"
-    pip3 install setuptools
-    pip3 install  -I -r "${TEST_DIR}/sanity-requirements-azure.txt"
-    pip3 list
-else
-    pip3 install  -I -r "${TEST_DIR}/requirements-azure.txt"
-    pip3 install  -I -r "${TEST_DIR}/sanity-requirements-azure.txt"
-    pip3 list
-fi
+pip install  -I -r "${TEST_DIR}/requirements-azure.txt"
+pip install  -I -r "${TEST_DIR}/sanity-requirements-azure.txt"
 
-timeout=60
+timeout=90
 
 if [ "$4" = "all" ]
 then
@@ -110,6 +75,7 @@ else
     done
 fi
 echo '--------------------------------------------'
+pip list
 ansible --version
 echo '--------------------------------------------'
 
