@@ -151,22 +151,18 @@ def main():
     )
 
     schema = module.params.get('schema')
-    template = module.params.get('template')
+    template = module.params.get('template').replace(' ', '')
     l3out = module.params.get('l3out')
     display_name = module.params.get('display_name')
     vrf = module.params.get('vrf')
+    if vrf is not None and vrf.get('template') is not None:
+        vrf['template'] = vrf.get('template').replace(' ', '')
     state = module.params.get('state')
 
     mso = MSOModule(module)
 
-    # Get schema_id
-    schema_obj = mso.get_obj('schemas', displayName=schema)
-    if schema_obj:
-        schema_id = schema_obj.get('id')
-    else:
-        mso.fail_json(msg="Provided schema '{0}' does not exist".format(schema))
-
-    schema_path = 'schemas/{id}'.format(**schema_obj)
+    # Get schema objects
+    schema_id, schema_path, schema_obj = mso.query_schema(schema)
 
     # Get template
     templates = [t.get('name') for t in schema_obj.get('templates')]
@@ -175,7 +171,7 @@ def main():
     template_idx = templates.index(template)
 
     # Get L3out
-    l3outs = [l.get('name') for l in schema_obj.get('templates')[template_idx]['intersiteL3outs']]
+    l3outs = [l3.get('name') for l3 in schema_obj.get('templates')[template_idx]['intersiteL3outs']]
 
     if l3out is not None and l3out in l3outs:
         l3out_idx = l3outs.index(l3out)
