@@ -103,17 +103,26 @@ EXAMPLES = r"""
                 | items2dict(key_name='slug',
                              value_name='itemValue'))['password']
             }}
-"""
 
+- hosts: localhost
+  vars:
+      secret_password: >-
+        {{ ((lookup('community.general.tss', 1) | from_json).get('items') | items2dict(key_name='slug', value_name='itemValue'))['password'] }}"
+  tasks:
+      - ansible.builtin.debug:
+          msg: the password is {{ secret_password }}
+"""
+from distutils.version import LooseVersion
 from ansible.errors import AnsibleError, AnsibleOptionsError
 
 sdk_is_missing = False
 
 try:
+    from thycotic import __version__ as sdk_version
     from thycotic.secrets.server import (
         SecretServer,
-        SecretServerAccessError,
         SecretServerError,
+        PasswordGrantAuthorizer,
     )
 except ImportError:
     sdk_is_missing = True
@@ -128,7 +137,20 @@ display = Display()
 class LookupModule(LookupBase):
     @staticmethod
     def Client(server_parameters):
-        return SecretServer(**server_parameters)
+
+        if LooseVersion(sdk_version) < LooseVersion('1.0.0'):
+            return SecretServer(**server_parameters)
+        else:
+            authorizer = PasswordGrantAuthorizer(
+                server_parameters["base_url"],
+                server_parameters["username"],
+                server_parameters["password"],
+                server_parameters["token_path_uri"],
+            )
+
+            return SecretServer(
+                server_parameters["base_url"], authorizer, server_parameters["api_path_uri"]
+            )
 
     def run(self, terms, variables, **kwargs):
         if sdk_is_missing:
