@@ -34,12 +34,15 @@ DOCUMENTATION = """
       required: True
     token:
       description:
-        - Vault token. Token may be specified explicitly, through the listed env var, and also through the C(VAULT_TOKEN) env var.
+        - Vault token. Token may be specified explicitly, through the listed [env] vars, and also through the C(VAULT_TOKEN) env var.
         - If no token is supplied, explicitly or through env, then the plugin will check for a token file, as determined by I(token_path) and I(token_file).
-        - The order of token loading (first found wins) is C(token param -> ANSIBLE_HASHI_VAULT_TOKEN -> VAULT_TOKEN -> token file).
+        - The order of token loading (first found wins) is C(token param -> ansible var -> ANSIBLE_HASHI_VAULT_TOKEN -> VAULT_TOKEN -> token file).
       env:
         - name: ANSIBLE_HASHI_VAULT_TOKEN
           version_added: '0.2.0'
+      vars:
+        - name: ansible_hashi_vault_token
+          version_added: '1.2.0'
     token_path:
       description: If no token is specified, will try to read the I(token_file) from this path.
       env:
@@ -54,6 +57,9 @@ DOCUMENTATION = """
       ini:
         - section: lookup_hashi_vault
           key: token_path
+      vars:
+        - name: ansible_hashi_vault_token_path
+          version_added: '1.2.0'
     token_file:
       description: If no token is specified, will try to read the token from this file in I(token_path).
       env:
@@ -68,6 +74,9 @@ DOCUMENTATION = """
       ini:
         - section: lookup_hashi_vault
           key: token_file
+      vars:
+        - name: ansible_hashi_vault_token_file
+          version_added: '1.2.0'
       default: '.vault-token'
     token_validate:
       description:
@@ -78,13 +87,28 @@ DOCUMENTATION = """
       ini:
         - section: lookup_hashi_vault
           key: token_validate
+      vars:
+        - name: ansible_hashi_vault_token_validate
+          version_added: '1.2.0'
       type: boolean
       default: true
       version_added: 0.2.0
     username:
       description: Authentication user name.
+      env:
+        - name: ANSIBLE_HASHI_VAULT_USERNAME
+          version_added: '1.2.0'
+      vars:
+        - name: ansible_hashi_vault_username
+          version_added: '1.2.0'
     password:
       description: Authentication password.
+      env:
+        - name: ANSIBLE_HASHI_VAULT_PASSWORD
+          version_added: '1.2.0'
+      vars:
+        - name: ansible_hashi_vault_password
+          version_added: '1.2.0'
     role_id:
       description: Vault Role ID. Used in approle and aws_iam_login auth methods.
       env:
@@ -99,6 +123,9 @@ DOCUMENTATION = """
       ini:
         - section: lookup_hashi_vault
           key: role_id
+      vars:
+        - name: ansible_hashi_vault_role_id
+          version_added: '1.2.0'
     secret_id:
       description: Secret ID to be used for Vault AppRole authentication.
       env:
@@ -110,9 +137,13 @@ DOCUMENTATION = """
             alternatives: ANSIBLE_HASHI_VAULT_SECRET_ID
         - name: ANSIBLE_HASHI_VAULT_SECRET_ID
           version_added: '0.2.0'
+      vars:
+        - name: ansible_hashi_vault_secret_id
+          version_added: '1.2.0'
     auth_method:
       description:
         - Authentication method to be used.
+        - C(none) auth method was added in collection version C(1.2.0).
       env:
         - name: VAULT_AUTH_METHOD
           deprecated:
@@ -125,6 +156,9 @@ DOCUMENTATION = """
       ini:
         - section: lookup_hashi_vault
           key: auth_method
+      vars:
+        - name: ansible_hashi_vault_auth_method
+          version_added: '1.2.0'
       choices:
         - token
         - userpass
@@ -132,6 +166,7 @@ DOCUMENTATION = """
         - approle
         - aws_iam_login
         - jwt
+        - none
       default: token
     return_format:
       description:
@@ -292,6 +327,14 @@ EXAMPLES = """
   ansible.builtin.debug:
     msg: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/hello:value', token=my_token, token_validate=False) }}"
 
+# "none" auth method does no authentication and does not send a token to the Vault address.
+# One example of where this could be used is with a Vault agent where the agent will handle authentication to Vault.
+# https://www.vaultproject.io/docs/agent
+
+- name: authenticate with vault agent
+  ansible.builtin.debug:
+    msg: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/hello:value', auth_method='none', url='http://127.0.0.1:8100') }}"
+
 # Use a proxy
 
 - name: use a proxy with login/password
@@ -314,13 +357,48 @@ EXAMPLES = """
   ansible.builtin.debug:
     msg: "{{ lookup('community.hashi_vault.hashi_vault', '...', proxies=prox }}"
 
-- name: use proxies with a dict (in the term string, Ansible key=value syntax)
+- name: use proxies with a dict (as direct ansible var)
+  vars:
+    ansible_hashi_vault_proxies:
+      http: http://myproxy1
+      https: https://myproxy2
   ansible.builtin.debug:
-    msg: "{{ lookup('community.hashi_vault.hashi_vault', '... proxies=http=http://myproxy1,https=http://myproxy2') }}"
+    msg: "{{ lookup('community.hashi_vault.hashi_vault', '...' }}"
 
 - name: use proxies with a dict (in the term string, JSON syntax)
   ansible.builtin.debug:
     msg: "{{ lookup('community.hashi_vault.hashi_vault', '... proxies={\\"http\\":\\"http://myproxy1\\",\\"https\\":\\"http://myproxy2\\"}') }}"
+
+- name: use ansible vars to supply some options
+  vars:
+    ansible_hashi_vault_url: 'https://myvault:8282'
+    ansible_hashi_vault_auth_method: token
+  set_fact:
+    secret1: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/data/secret1') }}"
+    secret2: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/data/secret2') }}"
+
+- name: use a custom timeout
+  debug:
+    msg: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/data/secret1', timeout=120) }}"
+
+- name: use a custom timeout and retry on failure 3 times (with collection retry defaults)
+  vars:
+    ansible_hashi_vault_timeout: 5
+    ansible_hashi_vault_retries: 3
+  debug:
+    msg: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/data/secret1') }}"
+
+- name: retry on failure (with custom retry settings and no warnings)
+  vars:
+    ansible_hashi_vault_retries:
+      total: 6
+      backoff_factor: 0.9
+      status_forcelist: [500, 502]
+      allowed_methods:
+        - GET
+        - PUT
+  debug:
+    msg: "{{ lookup('community.hashi_vault.hashi_vault', 'secret/data/secret1', retry_action='warn') }}"
 """
 
 RETURN = """
@@ -529,6 +607,8 @@ class HashiVault:
         except (NotImplementedError, AttributeError):
             raise AnsibleError("JWT authentication requires HVAC version 0.10.5 or higher.")
 
+    def auth_none(self):
+        pass
     # end auth implementation methods
 
 
@@ -542,8 +622,8 @@ class LookupModule(HashiVaultLookupBase):
         for term in terms:
             opts = kwargs.copy()
             opts.update(self.parse_kev_term(term, first_unqualified='secret', plugin_name='hashi_vault'))
-            self.set_options(direct=opts)
-            # TODO: remove deprecate() if backported fix is available (see method definition)
+            self.set_options(direct=opts, var_options=variables)
+            # TODO: remove process_deprecations() if backported fix is available (see method definition)
             self.process_deprecations()
             self.process_options()
             # passing connection_options and adapter to the HashiVault class to make transition easier
@@ -599,7 +679,7 @@ class LookupModule(HashiVaultLookupBase):
     def auth_methods(self):
         # enforce and set the list of available auth methods
         # TODO: can this be read from the choices: field in documentation?
-        avail_auth_methods = ['token', 'approle', 'userpass', 'ldap', 'aws_iam_login', 'jwt']
+        avail_auth_methods = ['token', 'approle', 'userpass', 'ldap', 'aws_iam_login', 'jwt', 'none']
         self.set_option('avail_auth_methods', avail_auth_methods)
         auth_method = self.get_option('auth_method')
 
@@ -694,4 +774,6 @@ class LookupModule(HashiVaultLookupBase):
     def validate_auth_jwt(self, auth_method):
         self.validate_by_required_fields(auth_method, 'role_id', 'jwt')
 
+    def validate_auth_none(self, auth_method):
+        pass
     # end auth method validators
