@@ -17,6 +17,9 @@
 # along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+from __future__ import absolute_import, division, print_function
+__metaclass__ = type
+
 from ansible_collections.community.network.tests.unit.compat.mock import patch, Mock, MagicMock, call
 from ansible_collections.community.network.tests.unit.plugins.modules.utils import set_module_args
 from .netscaler_module import TestModule, nitro_base_patcher
