@@ -54,6 +54,8 @@ author:
 extends_documentation_fragment:
 - community.postgresql.postgres
 
+notes:
+- Supports C(check_mode).
 '''
 
 EXAMPLES = r'''
@@ -117,6 +119,24 @@ version:
       returned: always
       type: int
       sample: 1
+    patch:
+      description: Patch server version.
+      returned: if supported
+      type: int
+      sample: 5
+      version_added: '1.2.0'
+    full:
+      description: Full server version.
+      returned: always
+      type: str
+      sample: '13.2'
+      version_added: '1.2.0'
+    raw:
+      description: Full output returned by ``SELECT version()``.
+      returned: always
+      type: str
+      sample: 'PostgreSQL 13.2 on x86_64-pc-linux-gnu, compiled by gcc (GCC) 10.2.1 20201125 (Red Hat 10.2.1-9), 64-bit'
+      version_added: '1.2.0'
 in_recovery:
   description: Indicates if the service is in recovery mode or not.
   returned: always
@@ -857,7 +877,7 @@ class PgClusterInfo(object):
         self.pg_info["settings"] = set_dict
 
     def get_repl_info(self):
-        """Get information about replication if the server is a master."""
+        """Get information about replication if the server is a primary."""
         # Check that pg_replication_slots exists:
         res = self.__exec_sql("SELECT EXISTS (SELECT 1 FROM "
                               "information_schema.tables "
@@ -923,12 +943,25 @@ class PgClusterInfo(object):
         """Get major and minor PostgreSQL server version."""
         query = "SELECT version()"
         raw = self.__exec_sql(query)[0][0]
-        raw = raw.split()[1].split('.')
+        full = raw.split()[1]
+        tmp = full.split('.')
+
+        major = int(tmp[0])
+        minor = int(tmp[1].rstrip(','))
+        patch = None
+        if len(tmp) >= 3:
+            patch = int(tmp[2].rstrip(','))
+
         self.pg_info["version"] = dict(
-            major=int(raw[0]),
-            minor=int(raw[1]),
+            major=major,
+            minor=minor,
+            full=full,
+            raw=raw,
         )
 
+        if patch is not None:
+            self.pg_info["version"]["patch"] = patch
+
     def get_recovery_state(self):
         """Get if the service is in recovery mode."""
         self.pg_info["in_recovery"] = self.__exec_sql("SELECT pg_is_in_recovery()")[0][0]
