@@ -94,8 +94,10 @@ options:
     - Whether the state is reported as changed or not
       is determined by the last statement of the file.
     - Used only when I(path_to_script) is specified, otherwise ignored.
+    - If set to C(no), the script can contain only semicolon-separated queries.
+      (see the I(path_to_script) option documentation).
+    - The default value is C(no).
     type: bool
-    default: no
     version_added: '1.1.0'
 seealso:
 - module: community.postgresql.postgresql_db
@@ -272,6 +274,8 @@ except ImportError:
     # ansible.module_utils.postgres
     pass
 
+import datetime
+import decimal
 import re
 
 from ansible.module_utils.basic import AnsibleModule
@@ -352,7 +356,7 @@ def main():
         encoding=dict(type='str'),
         trust_input=dict(type='bool', default=True),
         search_path=dict(type='list', elements='str'),
-        as_single_query=dict(type='bool', default=False),
+        as_single_query=dict(type='bool'),
     )
 
     module = AnsibleModule(
@@ -372,6 +376,13 @@ def main():
     search_path = module.params["search_path"]
     as_single_query = module.params["as_single_query"]
 
+    if path_to_script and as_single_query is None:
+        module.warn('You use the "path_to_script" option with the "as_single_query" '
+                    'option unset. The default is False and will be changed to True '
+                    'in community.postgresql release 2.0.0. '
+                    'To avoid crashes, please read the documentation '
+                    'and define the "as_single_query" option explicitly.')
+
     if not trust_input:
         # Check input for potentially dangerous elements:
         check_input(module, session_role)
@@ -439,8 +450,20 @@ def main():
             if cursor.rowcount > 0:
                 rowcount += cursor.rowcount
 
+            query_result = []
             try:
-                query_result = [dict(row) for row in cursor.fetchall()]
+                for row in cursor.fetchall():
+                    # Ansible engine does not support decimals.
+                    # An explicit conversion is required on the module's side
+                    row = dict(row)
+                    for (key, val) in iteritems(row):
+                        if isinstance(val, decimal.Decimal):
+                            row[key] = float(val)
+
+                        elif isinstance(val, datetime.timedelta):
+                            row[key] = str(val)
+
+                    query_result.append(row)
 
             except Psycopg2ProgrammingError as e:
                 if to_native(e) == 'no results to fetch':
