@@ -178,7 +178,7 @@ class PodmanModuleParams:
 
        Arguments:
            action {str} -- action type from 'run', 'stop', 'create', 'delete',
-                           'start'
+                           'start', 'restart'
            params {dict} -- dictionary of module parameters
 
        """
@@ -195,7 +195,7 @@ class PodmanModuleParams:
         Returns:
            list -- list of byte strings for Popen command
         """
-        if self.action in ['start', 'stop', 'delete']:
+        if self.action in ['start', 'stop', 'delete', 'restart']:
             return self.start_stop_delete()
         if self.action in ['create', 'run']:
             cmd = [self.action, '--name', self.params['name']]
@@ -217,7 +217,7 @@ class PodmanModuleParams:
 
     def start_stop_delete(self):
 
-        if self.action in ['stop', 'start']:
+        if self.action in ['stop', 'start', 'restart']:
             cmd = [self.action, self.params['name']]
             return [to_bytes(i, errors='surrogate_or_strict') for i in cmd]
 
@@ -759,6 +759,11 @@ class PodmanContainerDiff:
     def diffparam_cidfile(self):
         before = self.info['hostconfig']['containeridfile']
         after = self.params['cidfile']
+        labels = self.info['config']['labels'] or {}
+        # Ignore cidfile that is coming from systemd files
+        # https://github.com/containers/ansible-podman-collections/issues/276
+        if 'podman_systemd_unit' in labels:
+            after = before
         return self._diff_update_and_compare('cidfile', before, after)
 
     def diffparam_command(self):
@@ -924,6 +929,11 @@ class PodmanContainerDiff:
                 str(k).lower(): str(v)
                 for k, v in self.params['label'].items()
             })
+        # Strip out labels that are coming from systemd files
+        # https://github.com/containers/ansible-podman-collections/issues/276
+        if 'podman_systemd_unit' in before:
+            after.pop('podman_systemd_unit', None)
+            before.pop('podman_systemd_unit', None)
         return self._diff_update_and_compare('label', before, after)
 
     def diffparam_log_driver(self):
@@ -1063,16 +1073,6 @@ class PodmanContainerDiff:
         before, after = sorted(list(set(before))), sorted(list(set(after)))
         return self._diff_update_and_compare('network', before, after)
 
-    def diffparam_no_hosts(self):
-        before = not bool(self.info['hostspath'])
-        # For newer verions of Podman
-        if 'resolvconfpath' in self.info:
-            before = not bool(self.info['resolvconfpath'])
-        after = self.params['no_hosts']
-        if self.params['network'] == ['none']:
-            after = True
-        return self._diff_update_and_compare('no_hosts', before, after)
-
     def diffparam_oom_score_adj(self):
         before = self.info['hostconfig']['oomscoreadj']
         after = self.params['oom_score_adj']
@@ -1395,7 +1395,7 @@ class PodmanContainer:
 
         Arguments:
             action {str} -- action to perform - start, create, stop, run,
-                            delete
+                            delete, restart
         """
         b_command = PodmanModuleParams(action,
                                        self.module_params,
@@ -1442,6 +1442,10 @@ class PodmanContainer:
         """Start the container."""
         self._perform_action('start')
 
+    def restart(self):
+        """Restart the container."""
+        self._perform_action('restart')
+
     def create(self):
         """Create the container."""
         self._perform_action('create')
@@ -1460,11 +1464,6 @@ class PodmanContainer:
         self.delete()
         self.run()
 
-    def restart(self):
-        """Restart the container."""
-        self.stop()
-        self.start()
-
 
 class PodmanManager:
     """Module manager class.
@@ -1519,6 +1518,20 @@ class PodmanManager:
 
     def make_started(self):
         """Run actions if desired state is 'started'."""
+        if not self.image:
+            if not self.container.exists:
+                self.module.fail_json(msg='Cannot start container when image'
+                                          ' is not specified!')
+            if self.restart:
+                self.container.restart()
+                self.results['actions'].append('restarted %s' %
+                                               self.container.name)
+            else:
+                self.container.start()
+                self.results['actions'].append('started %s' %
+                                               self.container.name)
+            self.update_container_result()
+            return
         if self.container.exists and self.restart:
             if self.container.running:
                 self.container.restart()
@@ -1578,6 +1591,21 @@ class PodmanManager:
                 self.container.recreate()
                 self.results['actions'].append('recreated %s' %
                                                self.container.name)
+                if self.container.running:
+                    self.container.start()
+                    self.results['actions'].append('started %s' %
+                                                   self.container.name)
+                self.update_container_result()
+                return
+            elif self.restart:
+                if self.container.running:
+                    self.container.restart()
+                    self.results['actions'].append('restarted %s' %
+                                                   self.container.name)
+                else:
+                    self.container.start()
+                    self.results['actions'].append('started %s' %
+                                                   self.container.name)
                 self.update_container_result()
                 return
             self.update_container_result(changed=False)
@@ -1616,7 +1644,7 @@ class PodmanManager:
     def execute(self):
         """Execute the desired action according to map of actions & states."""
         states_map = {
-            'present': self.make_started,
+            'present': self.make_created,
             'started': self.make_started,
             'absent': self.make_absent,
             'stopped': self.make_stopped,
