@@ -7,17 +7,12 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_monitor_tcp
-short_description: Manages F5 BIG-IP LTM tcp monitors
-description: Manages F5 BIG-IP LTM tcp monitors via iControl SOAP API.
-version_added: "1.4.0"
+short_description: Manages F5 BIG-IP LTM TCP monitors
+description: Manages F5 BIG-IP LTM TCP monitors via iControl REST API.
+version_added: "1.0.0"
 options:
   name:
     description:
@@ -37,35 +32,37 @@ options:
     type: str
   send:
     description:
-      - The send string for the monitor call.
+      - The Send string for the monitor call.
     type: str
   receive:
     description:
-      - The receive string for the monitor call.
+      - The Receive string for the monitor call.
     type: str
   receive_disable:
     description:
-      - The receive disable string for the monitor call.
+      - The Receive Disable string for the monitor call.
+        This setting works like C(receive), except the system marks the node
+        or pool member disabled when its response matches the C(receive_disable)
+        string but not C(receive). To use this setting, you must specify both
+        C(receive_disable) and C(receive).
     type: str
   ip:
     description:
       - IP address part of the IP/port definition. If this parameter is not
-        provided when creating a new monitor, then the default value will be
-        '*'.
+        provided when creating a new monitor, the default value is '*'.
       - If this value is an IP address, and the C(type) is C(tcp) (the default),
         then a C(port) number must be specified.
-      - In BIG IP Management UI, this field is titled as 'Alias Address'.
+      - In BIG IP Management UI, this field is B(Alias Address).
     aliases:
       - alias_address
     type: str
   port:
     description:
       - Port address part of the IP/port definition. If this parameter is not
-        provided when creating a new monitor, then the default value will be
-        '*'. Note that if specifying an IP address, a value between 1 and 65535
-        must be specified
+        provided when creating a new monitor, the default value is '*'.
+        If specifying an IP address, you must specify a value between 1 and 65535.
       - This argument is not supported for TCP Echo types.
-      - In BIG IP Management UI, this field is titled as 'Alias Service Port'.
+      - In BIG IP Management UI, this field is B(Alias Service Port).
     type: str
     aliases:
       - alias_service_port
@@ -73,7 +70,7 @@ options:
     description:
       - The interval specifying how frequently the monitor instance of this
         template will run. If this parameter is not provided when creating
-        a new monitor, then the default value will be 5. This value B(must)
+        a new monitor, the default value is 5. This value B(must)
         be less than the C(timeout) value.
     type: int
   timeout:
@@ -84,15 +81,15 @@ options:
         the set time period, it is considered down. You can change this
         number to any number you want, however, it should be 3 times the
         interval number of seconds plus 1 second. If this parameter is not
-        provided when creating a new monitor, then the default value will be 16.
+        provided when creating a new monitor, the default value is 16.
     type: int
   time_until_up:
     description:
       - Specifies the amount of time in seconds after the first successful
-        response before a node will be marked up. A value of 0 will cause a
+        response before a node will be marked up. A value of C(0) causes a
         node to be marked up immediately after a valid response is received
         from the node. If this parameter is not provided when creating
-        a new monitor, then the default value will be 0.
+        a new monitor, the default value is C(0).
     type: int
   partition:
     description:
@@ -101,7 +98,7 @@ options:
     default: Common
   state:
     description:
-      - When C(present), ensures that the monitor exists.
+      - When C(present), ensures the monitor exists.
       - When C(absent), ensures the monitor is removed.
     type: str
     choices:
@@ -147,7 +144,7 @@ parent:
   type: str
   sample: tcp
 send:
-  description: The new send string for this monitor.
+  description: The new Send string for this monitor.
   returned: changed
   type: str
   sample: tcp string to send
@@ -157,12 +154,12 @@ description:
   type: str
   sample: Important Monitor
 receive:
-  description: The new receive string for this monitor.
+  description: The new Receive string for this monitor.
   returned: changed
   type: str
   sample: tcp string to receive
 receive_disable:
-  description: The new receive disable string for this monitor.
+  description: The new Receive Disable string for this monitor.
   returned: changed
   type: str
   sample: tcp string to receive
@@ -177,7 +174,7 @@ port:
   type: str
   sample: admin@root.local
 interval:
-  description: The new interval in which to run the monitor check.
+  description: The new interval at which to run the monitor check.
   returned: changed
   type: int
   sample: 2
@@ -192,6 +189,7 @@ time_until_up:
   type: int
   sample: 2
 '''
+from datetime import datetime
 
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
@@ -203,6 +201,8 @@ from ..module_utils.common import (
 )
 from ..module_utils.compare import cmp_str_with_none
 from ..module_utils.ipaddress import is_valid_ip
+from ..module_utils.icontrol import tmos_version
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -467,6 +467,8 @@ class ModuleManager(object):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -481,6 +483,7 @@ class ModuleManager(object):
         result.update(**changes)
         result.update(dict(changed=changed))
         self._announce_deprecations(result)
+        send_teem(start, self.client, self.module, version)
         return result
 
     def _announce_deprecations(self, result):
