@@ -7,17 +7,12 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['stableinterface'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_profile_http2
 short_description: Manage HTTP2 profiles on a BIG-IP
 description:
-  - Manage HTTP2 profiles on a BIG-IP.
+  - Manage HTTP2 profiles on a BIG-IP system.
 version_added: "1.0.0"
 options:
   name:
@@ -37,13 +32,13 @@ options:
     type: str
   streams:
     description:
-      - Specifies the number of outstanding concurrent requests that are allowed on a single HTTP/2 connection.
+      - Specifies the number of outstanding concurrent requests allowed on a single HTTP/2 connection.
       - When creating a new profile, if this parameter is not specified, the default is provided by the parent profile.
       - The valid value range is C(1 - 256).
     type: int
   idle_timeout:
     description:
-      - Specifies the number of seconds that an HTTP/2 connection is idly left open before being shut down.
+      - Specifies the number of seconds an HTTP/2 connection is idly left open before being shut down.
       - When creating a new profile, if this parameter is not specified, the default is provided by the parent profile.
     type: int
   insert_header:
@@ -86,7 +81,7 @@ options:
     type: int
   receive_window:
     description:
-      - Specifies the way that the HTTP/2 profile performs flow control.
+      - Specifies the way the HTTP/2 profile performs flow control.
       - When creating a new profile, if this parameter is not specified, the default is provided by the parent profile.
       - The valid value range in kilobytes is C(16 - 128).
     type: int
@@ -103,7 +98,7 @@ options:
     default: Common
   state:
     description:
-      - When C(present), ensures that the profile exists.
+      - When C(present), ensures the profile exists.
       - When C(absent), ensures the profile is removed.
     type: str
     choices:
@@ -157,31 +152,32 @@ description:
   type: str
   sample: My profile
 insert_header_name:
-  description: Specifies the name of the HTTP2 header
+  description: Specifies the name of the HTTP2 header.
   returned: changed
   type: str
   sample: X-HTTP2
 streams:
-  description: The number of outstanding concurrent requests allowed on a single HTTP/2 connection
+  description: The number of outstanding concurrent requests allowed on a single HTTP/2 connection.
   returned: changed
   type: int
   sample: 30
 enforce_tls_requirements:
-  description: pecifies whether the system requires TLS for communications.
+  description: Specifies whether the system requires TLS for communications.
   returned: changed
   type: bool
   sample: yes
 frame_size:
-  description: The size of the data frames
+  description: The size of the data frames.
   returned: changed
   type: int
   sample: 30
 activation_modes:
-  description: Specifies HTTP/2 connection handling modes
+  description: Specifies HTTP/2 connection handling modes.
   returned: changed
   type: list
   sample: ['always']
 '''
+from datetime import datetime
 
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
@@ -191,6 +187,8 @@ from ..module_utils.bigip import F5RestClient
 from ..module_utils.common import (
     F5ModuleError, AnsibleF5Parameters, transform_name, f5_argument_spec, flatten_boolean, fq_name, is_empty_list
 )
+from ..module_utils.icontrol import tmos_version
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -452,6 +450,8 @@ class ModuleManager(object):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -465,6 +465,7 @@ class ModuleManager(object):
         result.update(**changes)
         result.update(dict(changed=changed))
         self._announce_deprecations(result)
+        send_teem(start, self.client, self.module, version)
         return result
 
     def _announce_deprecations(self, result):
