@@ -518,17 +518,31 @@ class ModuleManager(object):
         # version key can be missing in the event that an existing volume has
         # no installed software in it.
         if self.want.version != response.get('version', None):
+            if (response.get('active') is None) and response.get('status') == "complete":
+                if self.remove_volume():
+                    pass
             return False
+
         if self.want.build != response.get('build', None):
             return False
 
+        if (response.get('active') is None) and (response.get('status') == "complete"):
+            if self.remove_volume():
+                return False
+
         if self.want.state == 'installed':
             return True
         if self.want.state == 'activated':
-            if 'defaultBootLocation' in response['media'][0]:
+            if 'media' in response and 'defaultBootLocation' in response['media'][0]:
                 return True
         return False
 
+    def remove_volume(self):
+        delresp = self.client.api.delete(self.volume_url)
+        if delresp.status == 200:
+            time.sleep(60)
+            return True
+
     def exists(self):
         resp = self.client.api.get(self.volume_url)
 
