@@ -159,6 +159,29 @@ options:
                     - 'disabled'
                     - 'files'
                     - 'full-archive'
+                    - 'disable'
+                    - 'block'
+                    - 'monitor'
+            av-scan:
+                type: str
+                description: 'Enable AntiVirus scan service.'
+                choices:
+                    - 'disable'
+                    - 'monitor'
+                    - 'block'
+            external-blocklist:
+                type: str
+                description: 'Enable external-blocklist.'
+                choices:
+                    - 'disable'
+                    - 'monitor'
+                    - 'block'
+            quarantine:
+                type: str
+                description: 'Enable/disable quarantine for infected files.'
+                choices:
+                    - 'disable'
+                    - 'enable'
 
 '''
 
@@ -211,7 +234,10 @@ EXAMPLES = '''
               - quarantine
               - avquery
               - avmonitor
-            outbreak-prevention: <value in [disabled, files, full-archive]>
+            outbreak-prevention: <value in [disabled, files, full-archive, ...]>
+            av-scan: <value in [disable, monitor, block]>
+            external-blocklist: <value in [disable, monitor, block]>
+            quarantine: <value in [disable, enable]>
 
 '''
 
@@ -301,9 +327,29 @@ def main():
         'antivirus_profile_imap': {
             'required': False,
             'type': 'dict',
+            'revision': {
+                '6.0.0': True,
+                '6.2.1': True,
+                '6.2.3': True,
+                '6.2.5': True,
+                '6.4.0': True,
+                '6.4.2': True,
+                '6.4.5': True,
+                '7.0.0': True
+            },
             'options': {
                 'archive-block': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'choices': [
                         'encrypted',
@@ -319,6 +365,16 @@ def main():
                 },
                 'archive-log': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'choices': [
                         'encrypted',
@@ -334,6 +390,16 @@ def main():
                 },
                 'content-disarm': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         'disable',
                         'enable'
@@ -342,6 +408,16 @@ def main():
                 },
                 'emulator': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         'disable',
                         'enable'
@@ -350,6 +426,16 @@ def main():
                 },
                 'executables': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         'default',
                         'virus'
@@ -358,6 +444,16 @@ def main():
                 },
                 'options': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'choices': [
                         'scan',
@@ -369,10 +465,58 @@ def main():
                 },
                 'outbreak-prevention': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         'disabled',
                         'files',
-                        'full-archive'
+                        'full-archive',
+                        'disable',
+                        'block',
+                        'monitor'
+                    ],
+                    'type': 'str'
+                },
+                'av-scan': {
+                    'required': False,
+                    'revision': {
+                        '7.0.0': True
+                    },
+                    'choices': [
+                        'disable',
+                        'monitor',
+                        'block'
+                    ],
+                    'type': 'str'
+                },
+                'external-blocklist': {
+                    'required': False,
+                    'revision': {
+                        '7.0.0': True
+                    },
+                    'choices': [
+                        'disable',
+                        'monitor',
+                        'block'
+                    ],
+                    'type': 'str'
+                },
+                'quarantine': {
+                    'required': False,
+                    'revision': {
+                        '7.0.0': True
+                    },
+                    'choices': [
+                        'disable',
+                        'enable'
                     ],
                     'type': 'str'
                 }
@@ -392,7 +536,7 @@ def main():
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_partial_curd()
+        fmgr.process_partial_curd(argument_specs=module_arg_spec)
     else:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     module.exit_json(meta=module.params)
