@@ -24,7 +24,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_dvmdb_workflow_start
-short_description: Continue a workflow session. Start a new session if ID is not specified in the request.<br/><br/>Refer to workflow and wflog object for ...
+short_description: Continue a workflow session.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -103,7 +103,7 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Continue a workflow session. Start a new session if ID is not specified in the request.<br/><br/>Refer to workflow and wflog object for ...
+    - name: Continue a workflow session.
       fmgr_dvmdb_workflow_start:
          bypass_validation: False
          workspace_locking_adom: <value in [global, custom adom including root]>
@@ -194,6 +194,16 @@ def main():
         'dvmdb_workflow_start': {
             'required': False,
             'type': 'dict',
+            'revision': {
+                '6.0.0': True,
+                '6.2.1': True,
+                '6.2.3': True,
+                '6.2.5': True,
+                '6.4.0': True,
+                '6.4.2': True,
+                '6.4.5': True,
+                '7.0.0': True
+            },
             'options': {
                 'desc': {
                     'required': False,
@@ -219,7 +229,7 @@ def main():
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, None, url_params, module, connection, top_level_schema_name='workflow')
         fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_exec()
+        fmgr.process_exec(argument_specs=module_arg_spec)
     else:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     module.exit_json(meta=module.params)
