@@ -80,6 +80,12 @@ from ansible_collections.junipernetworks.junos.plugins.module_utils.network.juno
 from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.routing_instances.routing_instances import (
     Routing_instancesFacts,
 )
+from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.prefix_lists.prefix_lists import (
+    Prefix_listsFacts,
+)
+from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.logging_global.logging_global import (
+    Logging_globalFacts,
+)
 
 FACT_LEGACY_SUBSETS = dict(
     default=Default, hardware=Hardware, config=Config, interfaces=Interfaces
@@ -103,6 +109,8 @@ FACT_RESOURCE_SUBSETS = dict(
     bgp_global=Bgp_globalFacts,
     bgp_address_family=Bgp_address_familyFacts,
     routing_instances=Routing_instancesFacts,
+    prefix_lists=Prefix_listsFacts,
+    logging_global=Logging_globalFacts,
 )
 
 
