@@ -1,17 +1,15 @@
 #!/usr/bin/python
 
-# (c) 2018-2019, NetApp, Inc
+# (c) 2018-2020, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
+'''
+na_ontap_export_policy_rule
+'''
+
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['preview'],
-                    'supported_by': 'certified'}
-
-
 DOCUMENTATION = '''
 
 module: na_ontap_export_policy_rule
@@ -36,7 +34,7 @@ options:
 
   name:
     description:
-    - The name of the export rule to manage.
+    - The name of the export policy this rule will be added to (or modified, or removed from).
     required: True
     type: str
     aliases:
@@ -54,7 +52,7 @@ options:
   anonymous_user_id:
     description:
     - User name or ID to which anonymous users are mapped. Default value is '65534'.
-    type: int
+    type: str
 
   ro_rule:
     description:
@@ -92,7 +90,7 @@ options:
 
   rule_index:
     description:
-    - rule index of the export policy
+    - index of the export policy rule
     type: int
 
   vserver:
@@ -105,7 +103,7 @@ options:
 
 EXAMPLES = """
     - name: Create ExportPolicyRule
-      na_ontap_export_policy_rule:
+      netapp.ontap.na_ontap_export_policy_rule:
         state: present
         name: default123
         vserver: ci_dev
@@ -121,7 +119,7 @@ EXAMPLES = """
         password: "{{ netapp_password }}"
 
     - name: Modify ExportPolicyRule
-      na_ontap_export_policy_rule:
+      netapp.ontap.na_ontap_export_policy_rule:
         state: present
         name: default123
         rule_index: 100
@@ -136,7 +134,7 @@ EXAMPLES = """
         password: "{{ netapp_password }}"
 
     - name: Delete ExportPolicyRule
-      na_ontap_export_policy_rule:
+      netapp.ontap.na_ontap_export_policy_rule:
         state: absent
         name: default123
         rule_index: 100
@@ -186,7 +184,7 @@ class NetAppontapExportRule(object):
                                      choices=['any', 'none', 'never', 'krb5', 'krb5i', 'krb5p', 'ntlm', 'sys']),
             allow_suid=dict(required=False, type='bool'),
             rule_index=dict(required=False, type='int'),
-            anonymous_user_id=dict(required=False, type='int'),
+            anonymous_user_id=dict(required=False, type='str'),
             vserver=dict(required=True, type='str'),
         ))
 
@@ -208,6 +206,7 @@ class NetAppontapExportRule(object):
 
     def set_playbook_zapi_key_map(self):
         self.na_helper.zapi_string_keys = {
+            'anonymous_user_id': 'anonymous-user-id',
             'client_match': 'client-match',
             'name': 'policy-name'
         }
@@ -221,9 +220,7 @@ class NetAppontapExportRule(object):
             'allow_suid': 'is-allow-set-uid-enabled'
         }
         self.na_helper.zapi_int_keys = {
-            'rule_index': 'rule-index',
-            'anonymous_user_id': 'anonymous-user-id'
-
+            'rule_index': 'rule-index'
         }
 
     def set_query_parameters(self):
