@@ -230,6 +230,13 @@ options:
         choices: ['application', 'auto', 'lun']
         default: auto
         version_added: 21.2.0
+      exclude_aggregates:
+        description:
+          - The list of aggregate names to exclude when creating a volume.
+          - Requires ONTAP 9.9.1 GA or better.
+        type: list
+        elements: str
+        version_added: 21.7.0
 '''
 
 EXAMPLES = """
@@ -275,6 +282,7 @@ EXAMPLES = """
       lun_count: 3
       protection_type:
       local_policy: default
+      exclude_aggregates: aggr0
     hostname: "{{ netapp_hostname }}"
     username: "{{ netapp_username }}"
     password: "{{ netapp_password }}"
@@ -344,6 +352,7 @@ class NetAppOntapLUN(object):
             use_exact_size=dict(required=False, type='bool', default=True),
             san_application_template=dict(type='dict', options=dict(
                 use_san_application=dict(type='bool', default=True),
+                exclude_aggregates=dict(type='list', elements='str'),
                 name=dict(required=True, type='str'),
                 igroup_name=dict(type='str'),
                 lun_count=dict(type='int'),
@@ -583,7 +592,7 @@ class NetAppOntapLUN(object):
                 if value is not None:
                     application_component[attr] = value
         for attr in ('os_type', 'qos_policy_group', 'qos_adaptive_policy_group', 'total_size'):
-            if self.rest_api.get_ontap_version() < (9, 8):
+            if not self.rest_api.meets_rest_minimum_version(True, 9, 8, 0):
                 if attr in ('os_type', 'qos_policy_group', 'qos_adaptive_policy_group'):
                     # os_type and qos are not supported in 9.7 for the SAN application_component
                     continue
@@ -623,6 +632,11 @@ class NetAppOntapLUN(object):
                     value = self.na_helper.filter_out_none_entries(value)
                     if value:
                         san[attr] = value
+        for attr in ('exclude_aggregates',):
+            if modify is None:      # only used for create
+                values = self.na_helper.safe_get(self.parameters, ['san_application_template', attr])
+                if values:
+                    san[attr] = [dict(name=name) for name in values]
         for attr in ('os_type',):
             if not modify:      # not supported for modify operation, but required at application component level for create
                 value = self.na_helper.safe_get(self.parameters, [attr])
@@ -662,7 +676,7 @@ class NetAppOntapLUN(object):
         app_current, error = self.rest_app.get_application_uuid()
         self.fail_on_error(error)
         if app_current is None:
-            self.module.fail_json('Error: failed to create smart container for %s' % self.parameters['name'])
+            self.module.fail_json(msg='Error: failed to create smart container for %s' % self.parameters['name'])
         app_modify, app_modify_warning = self.app_changes(scope)
         if app_modify_warning is not None:
             self.module.warn(app_modify_warning)
@@ -813,7 +827,7 @@ class NetAppOntapLUN(object):
         if value is not None and (lun_count is None or lun_count == 1):
             self.parameters[attr] = value
             return
-        self.module.fail_json("Error: 'total_size' is a required SAN application template attribute when creating a LUN application")
+        self.module.fail_json(msg="Error: 'total_size' is a required SAN application template attribute when creating a LUN application")
 
     def validate_app_create(self):
         # fix total_size attribute
@@ -928,7 +942,7 @@ class NetAppOntapLUN(object):
             app_current, error = self.rest_app.get_application_uuid()
             self.fail_on_error(error)
             if scope == 'lun' and app_current is None:
-                self.module.fail_json('Application not found: %s.  scope=%s.' %
+                self.module.fail_json(msg='Application not found: %s.  scope=%s.' %
                                       (self.na_helper.safe_get(self.parameters, ['san_application_template', 'name']), scope))
         else:
             # no application template, fall back to LUN only
@@ -945,7 +959,7 @@ class NetAppOntapLUN(object):
                     if scope == 'application':
                         # volume already exists, but not as part of this application
                         app_cd_action = 'convert'
-                        if self.rest_api.get_ontap_version() < (9, 8):
+                        if not self.rest_api.meets_rest_minimum_version(True, 9, 8, 0):
                             msg = 'Error: converting a LUN volume to a SAN application container requires ONTAP 9.8 or better.'
                             self.module.fail_json(msg=msg)
                     else:
