@@ -8,10 +8,10 @@ __metaclass__ = type
 import json
 import pytest
 
-from ansible_collections.netapp.ontap.tests.unit.compat import unittest
-from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch, Mock
 from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
+from ansible_collections.netapp.ontap.tests.unit.compat import unittest
+from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch, Mock
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_net_routes \
@@ -25,17 +25,19 @@ SRR = {
     # common responses
     'is_rest': (200, {}, None),
     'is_zapi': (400, {}, "Unreachable"),
-    'empty_good': ({}, None),
-    'end_of_sequence': (None, "Unexpected call to send_request"),
-    'generic_error': (None, "Expected error"),
+    'empty_good': (200, {}, None),
+    'end_of_sequence': (500, None, "Unexpected call to send_request"),
+    'generic_error': (400, None, "Expected error"),
     # module specific responses
-    'net_routes_record': ({'records': [{"destination": {"address": "176.0.0.0",
+    'net_routes_record': (200,
+                          {'records': [{"destination": {"address": "176.0.0.0",
                                                         "netmask": "24",
                                                         "family": "ipv4"},
                                         "gateway": '10.193.72.1',
                                         "uuid": '1cd8a442-86d1-11e0-ae1c-123478563412',
                                         "svm": {"name": "test_vserver"}}]}, None),
-    'modified_record': ({'records': [{"destination": {"address": "0.0.0.0",
+    'modified_record': (200,
+                        {'records': [{"destination": {"address": "0.0.0.0",
                                                       "netmask": "0",
                                                       "family": "ipv4"},
                                       "gateway": "10.193.72.1",
@@ -52,12 +54,10 @@ def set_module_args(args):
 
 class AnsibleExitJson(Exception):
     """Exception class to be raised by module.exit_json and caught by the test case"""
-    pass
 
 
 class AnsibleFailJson(Exception):
     """Exception class to be raised by module.fail_json and caught by the test case"""
-    pass
 
 
 def exit_json(*args, **kwargs):  # pylint: disable=unused-argument
@@ -146,7 +146,8 @@ class TestMyModule(unittest.TestCase):
                 'from_gateway': self.mock_net_route['gateway'],
                 'hostname': 'test',
                 'username': 'test_user',
-                'password': 'test_pass!'
+                'password': 'test_pass!',
+                'use_rest': 'never'
             }
         else:
             return {
@@ -156,10 +157,11 @@ class TestMyModule(unittest.TestCase):
                 'metric': self.mock_net_route['metric'],
                 'hostname': 'test',
                 'username': 'test_user',
-                'password': 'test_pass!'
+                'password': 'test_pass!',
+                'use_rest': 'never'
             }
 
-    def get_net_route_mock_object(self, kind=None, data=None, type='zapi'):
+    def get_net_route_mock_object(self, kind=None, data=None, cx_type='zapi'):
         """
         Helper method to return an na_ontap_net_route object
         :param kind: passes this param to MockONTAPConnection()
@@ -168,7 +170,7 @@ class TestMyModule(unittest.TestCase):
         :return: na_ontap_net_route object
         """
         net_route_obj = net_route_module()
-        if type == 'zapi':
+        if cx_type == 'zapi':
             net_route_obj.ems_log_event = Mock(return_value=None)
             net_route_obj.cluster = Mock()
             net_route_obj.cluster.invoke_successfully = Mock()
@@ -365,8 +367,8 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleFailJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
-        assert exc.value.args[0]['msg'] == SRR['generic_error'][1]
+            self.get_net_route_mock_object(cx_type='rest').apply()
+        assert exc.value.args[0]['msg'] == SRR['generic_error'][2]
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
     def test_rest_successfully_create(self, mock_request):
@@ -380,7 +382,7 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleExitJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
+            self.get_net_route_mock_object(cx_type='rest').apply()
         assert exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
@@ -394,7 +396,7 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleExitJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
+            self.get_net_route_mock_object(cx_type='rest').apply()
         assert not exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
@@ -409,7 +411,7 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleExitJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
+            self.get_net_route_mock_object(cx_type='rest').apply()
         assert exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
@@ -423,13 +425,14 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleExitJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
+            self.get_net_route_mock_object(cx_type='rest').apply()
         assert not exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
     def test_rest_successfully_modify(self, mock_request):
         data = self.mock_args(modify=True)
         data['state'] = 'present'
+        data['use_rest'] = 'auto'
         set_module_args(data)
         mock_request.side_effect = [
             SRR['is_rest'],
@@ -442,13 +445,14 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleExitJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
+            self.get_net_route_mock_object(cx_type='rest').apply()
         assert exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
     def test_rest_idempotently_modify(self, mock_request):
         data = self.mock_args(modify=True)
         data['state'] = 'present'
+        data['use_rest'] = 'auto'
         set_module_args(data)
         mock_request.side_effect = [
             SRR['is_rest'],
@@ -457,5 +461,5 @@ class TestMyModule(unittest.TestCase):
             SRR['end_of_sequence']
         ]
         with pytest.raises(AnsibleExitJson) as exc:
-            self.get_net_route_mock_object(type='rest').apply()
+            self.get_net_route_mock_object(cx_type='rest').apply()
         assert not exc.value.args[0]['changed']
