@@ -17,6 +17,7 @@ author:
 - "Martin Necas (@mnecas)"
 description:
     - "Module to manage Virtual Machine and floating disks in oVirt/RHV."
+    - "WARNING: If you are installing the collection from ansible galaxy you need to install 'qemu-img' package."
 options:
     id:
         description:
@@ -77,7 +78,7 @@ options:
         description:
             - "Driver of the storage interface."
             - "It's required parameter when creating the new disk."
-        choices: ['virtio', 'ide', 'virtio_scsi']
+        choices: ['virtio', 'ide', 'sata', 'virtio_scsi']
         type: str
     format:
         description:
@@ -730,7 +731,7 @@ def main():
         vm_name=dict(default=None),
         vm_id=dict(default=None),
         size=dict(default=None),
-        interface=dict(default=None, choices=['virtio', 'ide', 'virtio_scsi']),
+        interface=dict(default=None, choices=['virtio', 'ide', 'sata', 'virtio_scsi']),
         storage_domain=dict(default=None),
         storage_domains=dict(default=None, type='list', elements='str'),
         profile=dict(default=None),
